from setuptools import setup

setup(
    name='datorama',
    version='0.8',
    packages=['datorama'],
    license='MIT',
    description='Datorama Python Package',
    url='https://github.com/datorama/python-connector-package',
    author='Asaad Awesat',
    author_email='asaad.awesat@datorama.com'
)
